@@ -30,12 +30,13 @@
 class GuessnetEnvironment : public Environment
 {
 protected:
-	// List of scans to perform
+	// List of tests to perform
 	std::vector<const Scan*> _scans;
 
 	virtual void parseConfigFile() = 0;
 	
 public:
+	virtual ~GuessnetEnvironment() {}
 	static void init(int argc, const char* argv[]);
 	static GuessnetEnvironment& get() throw ();
 	const std::vector<const Scan*> scans() throw () { return _scans; }
