@@ -61,7 +61,7 @@ void PeerScanner::handleARP(const NetBuffer& arp) throw ()
 				if (MAC_MATCHES(&(*i)->mac(), mac_him))
 				{
 					debug("ARP reply from %.*s %.*s matches\n", PFSTR(fmt(IPAddress(*ipv4_him))), PFSTR(fmt(*mac_him)));
-					found(*i);
+					succeeded(*i);
 				}
 				else
 				{
@@ -71,7 +71,7 @@ void PeerScanner::handleARP(const NetBuffer& arp) throw ()
 					if (MAC_MATCHES(&(*i)->mac(), &zeroAddr))
 					{
 						debug("ARP reply from %.*s %.*s matches\n", PFSTR(fmt(IPAddress(*ipv4_him))), PFSTR(fmt(*mac_him)));
-						found(*i);
+						succeeded(*i);
 					}
 				}
 			}
